@@ -47,6 +47,6 @@ $ #TabRotateVertical
 $ #SemiSloppyFocus
 #  
 $ #MaxOverSlit
-# Maximize Over Slit
+#   
 $ #SloppyWindowGrouping
-# Sloppy Window Grouping
+#  "" 
