@@ -2,7 +2,7 @@ $set 10 #Windowmenu
 
 $ #SendTo
 #   ...
-$ #Send Group To
+$ #SendGroupTo
 #   ...
 $ #Shade
 #   
@@ -21,4 +21,4 @@ $ #KillClient
 $ #Close
 # 
 $ #Tab
-# Tab
+#  
