@@ -22,7 +22,7 @@
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: Basemenu.cc,v 1.6 2002/01/11 09:26:33 fluxgen Exp $
+// $Id: Basemenu.cc,v 1.10 2002/02/08 13:47:11 fluxgen Exp $
 
 // stupid macros needed to access some functions in version 2 of the GNU C
 // library
@@ -49,6 +49,7 @@
 #	include <string.h>
 #endif // STDC_HEADERS
 
+#include <iostream>
 
 static Basemenu *shown = (Basemenu *) 0;
 
@@ -118,15 +119,15 @@ Basemenu::Basemenu(BScreen *scrn) {
 	
 	//set attributes for menu window
 	unsigned long attrib_mask = CWBackPixmap | CWBackPixel | CWBorderPixel |
-					CWColormap | CWOverrideRedirect | CWEventMask;
+		CWColormap | CWOverrideRedirect | CWEventMask;
 	XSetWindowAttributes attrib;
 	attrib.background_pixmap = None;
 	attrib.background_pixel = attrib.border_pixel =
-			screen->getBorderColor()->getPixel();
+		screen->getBorderColor()->getPixel();
 	attrib.colormap = screen->getColormap();
 	attrib.override_redirect = True;
 	attrib.event_mask = ButtonPressMask | ButtonReleaseMask |
-			ButtonMotionMask | ExposureMask;
+		ButtonMotionMask | ExposureMask;
 
 	//create menu window
 	menu.window =
@@ -155,8 +156,6 @@ Basemenu::Basemenu(BScreen *scrn) {
 				screen->getVisual(), attrib_mask, &attrib);
 	fluxbox->saveMenuSearch(menu.frame, this);
 
-	menuitems = new LinkedList<BasemenuItem>;
-
 	// even though this is the end of the constructor the menu is still not
 	// completely created.	items must be inserted and it must be update()'d
 }
@@ -168,12 +167,10 @@ Basemenu::~Basemenu(void) {
 	if (shown && shown->getWindowID() == getWindowID())
 		shown = (Basemenu *) 0;
 
-	int n = menuitems->count();
+	int n = menuitems.size() - 1;
 	for (int i = 0; i < n; ++i)
 		remove(0);
 
-	delete menuitems;
-
 	if (menu.label)
 		delete [] menu.label;
 
@@ -200,62 +197,70 @@ Basemenu::~Basemenu(void) {
 }
 
 
-int Basemenu::insert(const char *l, int function, const char *e, int pos) {
-	char *label = 0, *exec = 0;
-
-	if (l) label = StringUtil::strdup(l);
-	if (e) exec = StringUtil::strdup(e);
-
+int Basemenu::insert(const char *label, int function, const char *exec, int pos) {
 	BasemenuItem *item = new BasemenuItem(label, function, exec);
-	menuitems->insert(item, pos);
+	if (pos == -1) {
+		menuitems.push_back(item);
+	} else {
+		menuitems.insert(menuitems.begin() + pos, item);
+	}
 
-	return menuitems->count();
+	return menuitems.size();
 }
 
 
-int Basemenu::insert(const char *l, Basemenu *submenu, int pos) {
-	char *label = 0;
-
-	if (l) label = StringUtil::strdup(l);
-
+int Basemenu::insert(const char *label, Basemenu *submenu, int pos) {
 	BasemenuItem *item = new BasemenuItem(label, submenu);
-	menuitems->insert(item, pos);
+	if (pos == -1) {
+		menuitems.push_back(item);
+	} else {
+		menuitems.insert(menuitems.begin() + pos, item);
+	}
 
 	submenu->parent = this;
 
-	return menuitems->count();
+	return menuitems.size();
 }
 
 
 int Basemenu::insert(const char **ulabel, int pos, int function) {
-	BasemenuItem *item = new BasemenuItem(ulabel, function);
-	menuitems->insert(item, pos);
+	assert(ulabel);
+	BasemenuItem *item = new BasemenuItem(*ulabel, function);
+	if (pos == -1) {
+		menuitems.push_back(item);
+	} else {
+		menuitems.insert(menuitems.begin() + pos, item);
+	}
 
-	return menuitems->count();
+	return menuitems.size();
 }
 
 
 int Basemenu::remove(int index) {
-	if (index < 0 || index > menuitems->count()) return -1;
+	if (index < 0 || index >= menuitems.size()) {
+		#ifdef DEBUG
+		std::cout << "Bad index (" << index << ") given to Basemenu::remove()"
+		          << " -- should be between 0 and " << menuitems.size()-1
+		          << " inclusive."
+			          << std::endl;
+		#endif
+		return -1;
+	}
 
-	BasemenuItem *item = menuitems->remove(index);
+	Menuitems::iterator it = menuitems.begin() + index;
+	BasemenuItem *item = (*it);
 
 	if (item) {
+		menuitems.erase(it);
 		if ((! internal_menu) && (item->submenu())) {
 			Basemenu *tmp = (Basemenu *) item->submenu();
 
 			if (! tmp->internal_menu) {
-	delete tmp;
+				delete tmp;				
 			} else
-	tmp->internal_hide();
+				tmp->internal_hide();
 		}
-
-		if (item->label())
-			delete [] item->label();
 		
-		if (item->exec())
-			delete [] item->exec();
-
 		delete item;
 	}
 
@@ -264,7 +269,7 @@ int Basemenu::remove(int index) {
 	else if (which_sub > index)
 		which_sub--;
 
-	return menuitems->count();
+	return menuitems.size();
 }
 
 
@@ -275,7 +280,7 @@ void Basemenu::update(void) {
 		menu.item_h = screen->getMenuStyle()->framefont.set_extents->max_ink_extent.height +
 			menu.bevel_w;
 		menu.title_h =	screen->getMenuStyle()->titlefont.set_extents->max_ink_extent.height +
-				(menu.bevel_w * 2);
+			(menu.bevel_w * 2);
 	} else {
 		menu.item_h = screen->getMenuStyle()->framefont.fontstruct->ascent +
 			screen->getMenuStyle()->framefont.fontstruct->descent +
@@ -309,12 +314,12 @@ void Basemenu::update(void) {
 		menu.item_w = 1;
 
 	int ii = 0;
-	LinkedListIterator<BasemenuItem> it(menuitems);
-	for (; it.current(); it++) {
-		BasemenuItem *itmp = it.current();
+	Menuitems::iterator it = menuitems.begin();
+	Menuitems::iterator it_end = menuitems.end();
+	for (; it != it_end; ++it) {
+		BasemenuItem *itmp = (*it);
 
-		const char *s = ((itmp->u && *itmp->u) ? *itmp->u :
-				 ((itmp->l) ? itmp->l : (const char *) 0));
+		const char *s = itmp->label();
 		int l = strlen(s);
 
 		if (i18n->multibyte()) {
@@ -329,18 +334,18 @@ void Basemenu::update(void) {
 		menu.item_w = ((menu.item_w < (unsigned int) ii) ? ii : menu.item_w);
 	}
 
-	if (menuitems->count()) {
+	if (menuitems.size()) {
 		menu.sublevels = 1;
 
-		while (((menu.item_h * (menuitems->count() + 1) / menu.sublevels)
+		while (((menu.item_h * (menuitems.size() + 1) / menu.sublevels)
 			+ menu.title_h + screen->getBorderWidth()) >
 		 screen->getHeight())
 			menu.sublevels++;
 
 		if (menu.sublevels < menu.minsub) menu.sublevels = menu.minsub;
 
-		menu.persub = menuitems->count() / menu.sublevels;
-		if (menuitems->count() % menu.sublevels) menu.persub++;
+		menu.persub = menuitems.size() / menu.sublevels;
+		if (menuitems.size() % menu.sublevels) menu.persub++;
 	} else {
 		menu.sublevels = 0;
 		menu.persub = 0;
@@ -422,7 +427,7 @@ void Basemenu::update(void) {
 	if (title_vis && visible) redrawTitle();
 
 	int i = 0;
-	for (i = 0; visible && i < menuitems->count(); i++)
+	for (i = 0; visible && i < menuitems.size(); i++)
 		if (i == which_sub) {
 			drawItem(i, True, 0);
 			drawSubmenu(i);
@@ -462,8 +467,8 @@ void Basemenu::hide(void) {
 
 
 void Basemenu::internal_hide(void) {
-	if (which_sub != -1) {
-		BasemenuItem *tmp = menuitems->find(which_sub);
+	if (which_sub >= 0) {
+		BasemenuItem *tmp = menuitems[which_sub];
 		tmp->submenu()->internal_hide();
 	}
 
@@ -537,15 +542,15 @@ void Basemenu::redrawTitle(void) {
 
 
 void Basemenu::drawSubmenu(int index) {
-	if (which_sub != -1 && which_sub != index) {
-		BasemenuItem *itmp = menuitems->find(which_sub);
+	if (which_sub >= 0 && which_sub != index) {
+		BasemenuItem *itmp = menuitems[which_sub];
 
 		if (! itmp->submenu()->isTorn())
 			itmp->submenu()->internal_hide();
 	}
 
-	if (index >= 0 && index < menuitems->count()) {
-		BasemenuItem *item = menuitems->find(index);
+	if (index >= 0 && index < menuitems.size()) {
+		BasemenuItem *item = menuitems[index];
 		if (item->submenu() && visible && (! item->submenu()->isTorn()) &&
 				item->isEnabled()) {
 			
@@ -606,8 +611,8 @@ void Basemenu::drawSubmenu(int index) {
 
 
 Bool Basemenu::hasSubmenu(int index) {
-	if ((index >= 0) && (index < menuitems->count()))
-		if (menuitems->find(index)->submenu())
+	if ((index >= 0) && (index < menuitems.size()))
+		if (menuitems[index]->submenu())
 			return True;
 		else
 			return False;
@@ -619,13 +624,13 @@ Bool Basemenu::hasSubmenu(int index) {
 void Basemenu::drawItem(int index, Bool highlight, Bool clear,
 			 int x, int y, unsigned int w, unsigned int h)
 {
-	if (index < 0 || index > menuitems->count()) return;
+	if (index < 0 || index > menuitems.size()) return;
 
-	BasemenuItem *item = menuitems->find(index);
+	BasemenuItem *item = menuitems[index];
 	if (! item) return;
 	
 	Bool dotext = True, dohilite = True, dosel = True;
-	const char *text = (item->ulabel()) ? *item->ulabel() : item->label();
+	const char *text = item->label();
 	int sbl = index / menu.persub, i = index - (sbl * menu.persub);
 	int item_x = (sbl * menu.item_w), item_y = (i * menu.item_h);
 	int hilite_x = item_x, hilite_y = item_y, hoff_x = 0, hoff_y = 0;
@@ -801,7 +806,7 @@ void Basemenu::setLabel(const char *l) {
 
 
 void Basemenu::setItemSelected(int index, Bool sel) {
-	if (index < 0 || index >= menuitems->count()) return;
+	if (index < 0 || index >= menuitems.size()) return;
 
 	BasemenuItem *item = find(index);
 	if (! item) return;
@@ -812,7 +817,7 @@ void Basemenu::setItemSelected(int index, Bool sel) {
 
 
 Bool Basemenu::isItemSelected(int index) {
-	if (index < 0 || index >= menuitems->count()) return False;
+	if (index < 0 || index >= menuitems.size()) return False;
 
 	BasemenuItem *item = find(index);
 	if (! item) return False;
@@ -822,7 +827,7 @@ Bool Basemenu::isItemSelected(int index) {
 
 
 void Basemenu::setItemEnabled(int index, Bool enable) {
-	if (index < 0 || index >= menuitems->count()) return;
+	if (index < 0 || index >= menuitems.size()) return;
 
 	BasemenuItem *item = find(index);
 	if (! item) return;
@@ -833,7 +838,7 @@ void Basemenu::setItemEnabled(int index, Bool enable) {
 
 
 Bool Basemenu::isItemEnabled(int index) {
-	if (index < 0 || index >= menuitems->count()) return False;
+	if (index < 0 || index >= menuitems.size()) return False;
 
 	BasemenuItem *item = find(index);
 	if (! item) return False;
@@ -847,11 +852,11 @@ void Basemenu::buttonPressEvent(XButtonEvent *be) {
 		int sbl = (be->x / menu.item_w), i = (be->y / menu.item_h);
 		int w = (sbl * menu.persub) + i;
 
-		if (w < menuitems->count() && w >= 0) {
+		if (w < menuitems.size() && w >= 0) {
 			which_press = i;
 			which_sbl = sbl;
 
-			BasemenuItem *item = menuitems->find(w);
+			BasemenuItem *item = menuitems[w];
 
 			if (item->submenu())
 				drawSubmenu(w);
@@ -870,7 +875,7 @@ void Basemenu::buttonReleaseEvent(XButtonEvent *re) {
 		if (moving) {
 			moving = False;
 			
-			if (which_sub != -1)
+			if (which_sub >= 0)
 				drawSubmenu(which_sub);
 		}
 		
@@ -890,7 +895,7 @@ void Basemenu::buttonReleaseEvent(XButtonEvent *re) {
 					w = (sbl * menu.persub) + i,
 					p = (which_sbl * menu.persub) + which_press;
 
-			if (w < menuitems->count() && w >= 0) {
+			if (w < menuitems.size() && w >= 0) {
 				drawItem(p, (p == which_sub), True);
 
 				if	(p == w && isItemEnabled(w)) {
@@ -917,7 +922,7 @@ void Basemenu::motionNotifyEvent(XMotionEvent *me) {
 
 				moving = torn = True;
 
-				if (which_sub != -1)
+				if (which_sub >= 0)
 					drawSubmenu(which_sub);
 			} else {
 				menu.x = me->x_root - menu.x_move,
@@ -925,7 +930,7 @@ void Basemenu::motionNotifyEvent(XMotionEvent *me) {
 	
 				XMoveWindow(display, menu.window, menu.x, menu.y);
 
-				if (which_sub != -1)
+				if (which_sub >= 0)
 					drawSubmenu(which_sub);
 			}
 		}
@@ -936,10 +941,10 @@ void Basemenu::motionNotifyEvent(XMotionEvent *me) {
 		w = (sbl * menu.persub) + i;
 
 		if ((i != which_press || sbl != which_sbl) &&
-				(w < menuitems->count() && w >= 0)) {
+				(w < menuitems.size() && w >= 0)) {
 			if (which_press != -1 && which_sbl != -1) {
 				int p = (which_sbl * menu.persub) + which_press;
-				BasemenuItem *item = menuitems->find(p);
+				BasemenuItem *item = menuitems[p];
 
 				drawItem(p, False, True);
 				if (item->submenu()) {
@@ -954,7 +959,7 @@ void Basemenu::motionNotifyEvent(XMotionEvent *me) {
 			which_press = i;
 			which_sbl = sbl;
 
-			BasemenuItem *itmp = menuitems->find(w);
+			BasemenuItem *itmp = menuitems[w];
 
 			if (itmp->submenu())
 				drawSubmenu(w);
@@ -969,8 +974,6 @@ void Basemenu::exposeEvent(XExposeEvent *ee) {
 	if (ee->window == menu.title) {
 		redrawTitle();
 	} else if (ee->window == menu.frame) {
-		LinkedListIterator<BasemenuItem> it(menuitems);
-
 		// this is a compilicated algorithm... lets do it step by step...
 		// first... we see in which sub level the expose starts... and how many
 		// items down in that sublevel
@@ -987,12 +990,16 @@ void Basemenu::exposeEvent(XExposeEvent *ee) {
 		int i, ii;
 		for (i = sbl; i <= sbl_d; i++) {
 			// set the iterator to the first item in the sublevel needing redrawing
-			it.set(id + (i * menu.persub));
-			for (ii = id; ii <= id_d && it.current(); it++, ii++) {
-				int index = ii + (i * menu.persub);
-				// redraw the item
-				drawItem(index, (which_sub == index), False,
-					 ee->x, ee->y, ee->width, ee->height);
+			int index = id + i * menu.persub;
+			if (index < menuitems.size() && index >= 0) {
+				Menuitems::iterator it = menuitems.begin() + index;
+				Menuitems::iterator it_end = menuitems.end();
+				for (ii = id; ii <= id_d && it != it_end; ++it, ii++) {
+					int index = ii + (i * menu.persub);
+					// redraw the item
+					drawItem(index, (which_sub == index), False,
+							ee->x, ee->y, ee->width, ee->height);
+				}
 			}
 		}
 	}
@@ -1023,8 +1030,8 @@ void Basemenu::enterNotifyEvent(XCrossingEvent *ce) {
 		if (shifted)
 			XMoveWindow(display, menu.window, menu.x_shift, menu.y_shift);
 
-		if (which_sub != -1) {
-			BasemenuItem *tmp = menuitems->find(which_sub);
+		if (which_sub >= 0) {
+			BasemenuItem *tmp = menuitems[which_sub];
 			if (tmp->submenu()->isVisible()) {
 				int sbl = (ce->x / menu.item_w), i = (ce->y / menu.item_h),
 				w = (sbl * menu.persub) + i;
@@ -1043,7 +1050,7 @@ void Basemenu::enterNotifyEvent(XCrossingEvent *ce) {
 
 void Basemenu::leaveNotifyEvent(XCrossingEvent *ce) {
 	if (ce->window == menu.frame) {
-		if (which_press != -1 && which_sbl != -1 && menuitems->count() > 0) {
+		if (which_press != -1 && which_sbl != -1 && menuitems.size() > 0) {
 			int p = (which_sbl * menu.persub) + which_press;
 
 			drawItem(p, (p == which_sub), True);
@@ -1055,7 +1062,7 @@ void Basemenu::leaveNotifyEvent(XCrossingEvent *ce) {
 			XMoveWindow(display, menu.window, menu.x, menu.y);
 			shifted = False;
 
-			if (which_sub != -1) drawSubmenu(which_sub);
+			if (which_sub >= 0) drawSubmenu(which_sub);
 		}
 	}
 }
