@@ -13,22 +13,23 @@
 //
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 // THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 // LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 // FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// $Id: Tab.cc,v 1.14 2002/01/09 14:11:20 fluxgen Exp $
+// $Id: Tab.cc,v 1.20 2002/02/04 06:50:48 fluxgen Exp $
 
 #include "Tab.hh"
 
 #ifdef HAVE_CONFIG_H
-#  include "../config.h"
+#	include "../config.h"
 #endif // HAVE_CONFIG_H
 
 #include "i18n.hh"
 #include "DrawUtil.hh"
+#include "Screen.hh"
 
 #include <iostream>
 using namespace std;
@@ -91,28 +92,29 @@ Tab::~Tab() {
 //-------------------------------------------------
 void Tab::createTabWindow() {
 	unsigned long attrib_mask = CWBackPixmap | CWBackPixel | CWBorderPixel |
-			      CWColormap | CWOverrideRedirect | CWEventMask;
+			CWColormap | CWOverrideRedirect | CWEventMask;
 	XSetWindowAttributes attrib;
 	attrib.background_pixmap = None;
 	attrib.background_pixel = attrib.border_pixel =
-			m_win->getScreen()->getWindowStyle()->tab.border_color.getPixel();
+		m_win->getScreen()->getWindowStyle()->tab.border_color.getPixel();
 	attrib.colormap = m_win->getScreen()->getColormap();
 	attrib.override_redirect = True;
 	attrib.event_mask = ButtonPressMask | ButtonReleaseMask |
-						ButtonMotionMask | ExposureMask | EnterWindowMask;
+		ButtonMotionMask | ExposureMask | EnterWindowMask;
 	//Notice that m_size_w gets the TOTAL width of tabs INCLUDING borders
 	m_tabwin = XCreateWindow(m_display, m_win->getScreen()->getRootWindow(), 
-							-30000, -30000, //TODO: So that it wont flicker or
-											// appear before the window do
-			m_size_w - m_win->getScreen()->getWindowStyle()->tab.border_width_2x,
-			m_size_h - m_win->getScreen()->getWindowStyle()->tab.border_width_2x,
-							m_win->getScreen()->getWindowStyle()->tab.border_width,
-							m_win->getScreen()->getDepth(), InputOutput,
-							m_win->getScreen()->getVisual(), attrib_mask, &attrib);
+		-30000, -30000, //TODO: So that it wont flicker or
+			// appear before the window do
+		m_size_w - m_win->getScreen()->getWindowStyle()->tab.border_width_2x,
+		m_size_h - m_win->getScreen()->getWindowStyle()->tab.border_width_2x,
+			m_win->getScreen()->getWindowStyle()->tab.border_width,
+			m_win->getScreen()->getDepth(), InputOutput,
+			m_win->getScreen()->getVisual(), attrib_mask, &attrib);
+
 	//set grab
 	XGrabButton(m_display, Button1, Mod1Mask, m_tabwin, True,
-				ButtonReleaseMask | ButtonMotionMask, GrabModeAsync,
-				GrabModeAsync, None, Fluxbox::instance()->getMoveCursor());
+		ButtonReleaseMask | ButtonMotionMask, GrabModeAsync,
+		GrabModeAsync, None, Fluxbox::instance()->getMoveCursor());
 
 	//save to tabsearch
 	Fluxbox::instance()->saveTabSearch(m_tabwin, this);	
@@ -150,11 +152,31 @@ void Tab::focus() {
 //-----------------------------------------
 void Tab::raise() {
 	//get first tab
-	Tab *first = 0;
-	first = getFirst(this);
+	Tab *tab = 0;
 	//raise tabs
-	for (; first!=0; first = first->m_next)
-		m_win->getScreen()->raiseWindows(&first->m_tabwin, 1);
+	for (tab = getFirst(this); tab!=0; tab = tab->m_next)
+		m_win->getScreen()->raiseWindows(&tab->m_tabwin, 1);
+}
+
+//-------------- lower --------------------
+// Lowers the tabs in the tablist AND
+// the windows the tabs relate to
+//-----------------------------------------
+void Tab::lower() {
+	Tab *current = this;
+	FluxboxWindow *win = 0; //convenience
+	//this have to be done in the correct order, otherwise we'll switch the window
+	//being ontop in the group
+	do { 
+		XLowerWindow(m_display, current->m_tabwin); //lower tabwin and tabs window
+		win = current->getWindow(); 
+		win->getScreen()->getWorkspace(win->getWorkspaceNumber())->lowerWindow(win);
+
+		current = current->next(); //get next
+		if (current == 0)
+			current = getFirst(this); //there weren't any after, get the first
+
+	} while (current != this);
 }
 
 //-------------- loadTheme -----------------
@@ -168,42 +190,43 @@ void Tab::loadTheme() {
 	Pixmap tmp = m_focus_pm;
 	BTexture *texture = &(m_win->getScreen()->getWindowStyle()->tab.l_focus);
 
- 	if (texture->getTexture() & BImage::PARENTRELATIVE ) {
+	if (texture->getTexture() & BImage::PARENTRELATIVE ) {
 		BTexture *pt = &(m_win->getScreen()->getWindowStyle()->tab.t_focus);
 		if (pt->getTexture() == (BImage::FLAT | BImage::SOLID)) {
-  		  m_focus_pm = None;
-	    m_focus_pixel = pt->getColor()->getPixel();
-  	} else
-    	m_focus_pm =
-	      image_ctrl->renderImage(m_size_w, m_size_h, pt);
-  	if (tmp) image_ctrl->removeImage(tmp);
-		
+			m_focus_pm = None;
+			m_focus_pixel = pt->getColor()->getPixel();
+		} else
+			m_focus_pm =
+				image_ctrl->renderImage(m_size_w, m_size_h, pt);
+
+		if (tmp) image_ctrl->removeImage(tmp);
+
 	} else {
 		if (texture->getTexture() == (BImage::FLAT | BImage::SOLID)) {
-  		  m_focus_pm = None;
-	    m_focus_pixel = texture->getColor()->getPixel();
-  	} else
-    	m_focus_pm =
-	      image_ctrl->renderImage(m_size_w, m_size_h, texture);
-  	if (tmp) image_ctrl->removeImage(tmp);
+			m_focus_pm = None;
+			m_focus_pixel = texture->getColor()->getPixel();
+		} else
+			m_focus_pm =
+				image_ctrl->renderImage(m_size_w, m_size_h, texture);
+		if (tmp) image_ctrl->removeImage(tmp);
 	}
-	
+
 	tmp = m_unfocus_pm;
 	texture = &(m_win->getScreen()->getWindowStyle()->tab.l_unfocus);
-  
+
 	if (texture->getTexture() & BImage::PARENTRELATIVE ) {
 		BTexture *pt = &(m_win->getScreen()->getWindowStyle()->tab.t_unfocus);
 		if (pt->getTexture() == (BImage::FLAT | BImage::SOLID)) {
 			m_unfocus_pm = None;
 			m_unfocus_pixel = pt->getColor()->getPixel();
-  		} else
+		} else
 			m_unfocus_pm =
 			image_ctrl->renderImage(m_size_w, m_size_h, pt);
 	} else {
 		if (texture->getTexture() == (BImage::FLAT | BImage::SOLID)) {
 			m_unfocus_pm = None;
 			m_unfocus_pixel = texture->getColor()->getPixel();
-  		} else
+		} else
 			m_unfocus_pm =
 				image_ctrl->renderImage(m_size_w, m_size_h, texture);
 	}
@@ -252,21 +275,18 @@ void Tab::withdraw() {
 // Set/reset the the sticky on all windows in the list
 //---------------------------------------
 void Tab::stick() {
+	Tab *tab;
  
-	//get first tab
-	Tab *first = 0;
-	first = getFirst(this);
-	
 	//now do stick for all windows in the list
-	for (; first!=0; first = first->m_next) {
-		FluxboxWindow *win = first->m_win; //just for convenient
+	for (tab = getFirst(this); tab != 0; tab = tab->m_next) {
+		FluxboxWindow *win = tab->m_win; //just for convenience
 		if (win->isStuck()) {
 			win->blackbox_attrib.flags ^= BaseDisplay::ATTRIB_OMNIPRESENT;
 			win->blackbox_attrib.attrib ^= BaseDisplay::ATTRIB_OMNIPRESENT;
 			win->stuck = false;
 			if (!win->isIconic())
-      	win->getScreen()->reassociateWindow(win, -1, true);
-				    
+				win->getScreen()->reassociateWindow(win, -1, true);
+
 		} else {
 			win->stuck = true;
 			win->blackbox_attrib.flags |= BaseDisplay::ATTRIB_OMNIPRESENT;
@@ -282,12 +302,12 @@ void Tab::stick() {
 // Resize the window's in the tablist
 //----------------------------------
 void Tab::resize() {
-	Tab *first = getFirst(this);
+	Tab *tab;
 
 	//now move and resize the windows in the list
-	for (; first != 0; first = first->m_next) {
-		if (first!=this) {
-			first->m_win->configure(m_win->getXFrame(), m_win->getYFrame(),
+	for (tab = getFirst(this); tab != 0; tab = tab->m_next) {
+		if (tab!=this) {
+			tab->m_win->configure(m_win->getXFrame(), m_win->getYFrame(),
 								m_win->getWidth(), m_win->getHeight());
 		}
 	}
@@ -303,10 +323,12 @@ void Tab::resize() {
 // Shades the windows in the tablist
 //--------------------------------
 void Tab::shade() {
-	for(Tab *first = getFirst(this); first != 0; first = first->m_next) {
-		if (first==this)
+	Tab *tab;
+
+	for(tab = getFirst(this); tab != 0; tab = tab->m_next) {
+		if (tab==this)
 			continue;
-		first->m_win->shade();
+		tab->m_win->shade();
 	}
 
 	if (m_win->getScreen()->getTabPlacement() == PLEFT ||
@@ -329,7 +351,7 @@ void Tab::draw(bool pressed) {
 	unsigned int tabtext_w;
 
 	GC gc = ((m_win->isFocused()) ? m_win->getScreen()->getWindowStyle()->tab.l_text_focus_gc :
-		   m_win->getScreen()->getWindowStyle()->tab.l_text_unfocus_gc);
+		m_win->getScreen()->getWindowStyle()->tab.l_text_unfocus_gc);
 
 	// Different routines for drawing rotated text
 	if ((m_win->getScreen()->getTabPlacement() == PLEFT ||
@@ -367,6 +389,75 @@ void Tab::draw(bool pressed) {
 	}
 }
 
+//-----------------------------------------------
+//Helper for the Tab::setPosition() call
+//returns the y position component correctly
+//according to shading in cases PBOTTOM and 
+//isShaded()
+//-----------------------------------------------
+int Tab::setPositionShadingHelper(bool shaded) {
+	if (shaded) {
+		return m_win->getYFrame() + m_win->getTitleHeight() + 
+				m_win->getScreen()->getBorderWidth2x();
+	} else {
+		return m_win->getYFrame() + m_win->getHeight() +
+				m_win->getScreen()->getBorderWidth2x();
+	}
+}
+
+//-----------------------------------------------
+//Helpers for correct alignment of tabs used
+//by the setPosition() call
+//return x/y positions correctly according to
+//alignment, the 1st for cases PTOP and PBOTTOM
+//the 2nd for cases PLEFT and PRIGHT
+//-----------------------------------------------
+int Tab::setPositionTBAlignHelper(Alignment align) {
+	switch(align) {
+
+	case ARELATIVE:
+	case ALEFT:
+		return m_win->getXFrame(); 
+		break;
+	case ACENTER:
+		return calcCenterXPos(); 
+		break;
+	case ARIGHT:
+		return m_win->getXFrame() + m_win->getWidth() +
+			m_win->getScreen()->getBorderWidth2x() - m_size_w;
+	default:
+#ifdef DEBUG
+		cerr << __FILE__ << ":" <<__LINE__ << ": " <<
+			"Unsupported Alignment" << endl;
+#endif //DEBUG
+		return 0;
+		break;
+	}
+}
+
+int Tab::setPositionLRAlignHelper(Alignment align) {
+	switch(align) {
+	case ALEFT:
+		return m_win->getYFrame() - m_size_h + m_win->getHeight() +
+				m_win->getScreen()->getBorderWidth2x();
+		break;
+	case ACENTER:
+		return calcCenterYPos();
+		break;
+	case ARELATIVE:
+	case ARIGHT:
+		return m_win->getYFrame();
+		break;
+	default:
+#ifdef DEBUG
+		cerr << __FILE__ << ":"<< __LINE__ << ": " <<
+			"Unsupported Alignment" << endl;
+#endif //DEBUG
+		return 0;
+		break;
+	}
+}
+
 //------------- setPosition -----------------
 // Position tab ( follow the m_win pos ).
 // (and resize)
@@ -377,85 +468,68 @@ void Tab::setPosition() {
 	if (m_stoptabs)
 		return;
 
-	Tab *first = 0;
+	Tab *tab;
 	int pos_x = 0, pos_y = 0;
 	
 	m_stoptabs = true; //freeze tablist
 	
 	//and check for max tabs
-	//TODO: optimize! There is many ways to implement this...		
-	//posible movement to a static member function
 
-	//Tab placement
-	if (m_win->getScreen()->getTabPlacement() == PTOP) {
-		pos_y = m_win->getYFrame() - m_size_h; 
-
-	} else if (m_win->getScreen()->getTabPlacement() == PBOTTOM ||
-				m_win->isShaded()) { 
-		if (m_win->isShaded())
-			pos_y = m_win->getYFrame() + m_win->getTitleHeight() +
-					m_win->getScreen()->getBorderWidth2x();
-
-		else
-			pos_y = m_win->getYFrame() + m_win->getHeight() +
-					m_win->getScreen()->getBorderWidth2x();
-
-	} else if (m_win->getScreen()->getTabPlacement() == PLEFT) {
-		pos_x = m_win->getXFrame() - m_size_w;
-			
-	} else if (m_win->getScreen()->getTabPlacement() == PRIGHT) {
-		pos_x = m_win->getXFrame() + m_win->getWidth() +
-				m_win->getScreen()->getBorderWidth2x();	
+	//Tab placement + alignment
+	switch (m_win->getScreen()->getTabPlacement()) {
+	case PTOP:
+		pos_y = m_win->getYFrame() - m_size_h;
+		pos_x = setPositionTBAlignHelper(
+				m_win->getScreen()->getTabAlignment());
+		break;
+	case PBOTTOM:
+		pos_y = setPositionShadingHelper(m_win->isShaded());
+		pos_x = setPositionTBAlignHelper(
+				m_win->getScreen()->getTabAlignment());
+		break;
+	case PLEFT:
+		pos_x = m_win->isShaded() ?
+			setPositionTBAlignHelper(m_win->getScreen()->getTabAlignment()) :
+			m_win->getXFrame() - m_size_w;
+		pos_y = m_win->isShaded() ?
+			setPositionShadingHelper(true) :
+			setPositionLRAlignHelper(m_win->getScreen()->getTabAlignment());
+		break;
+	case PRIGHT:
+		pos_x = m_win->isShaded() ?
+			setPositionTBAlignHelper(m_win->getScreen()->getTabAlignment()) :
+			m_win->getXFrame() + m_win->getWidth() +
+				m_win->getScreen()->getBorderWidth2x();
+		pos_y = m_win->isShaded() ?
+			setPositionShadingHelper(true) :
+			setPositionLRAlignHelper(m_win->getScreen()->getTabAlignment());
+		break;
+	default:
+		if(m_win->isShaded()) {
+			pos_y = setPositionShadingHelper(true);
+			pos_x = setPositionTBAlignHelper(
+				m_win->getScreen()->getTabAlignment());
+		} else {
+			setPositionShadingHelper(false);
+		}
+		break;
 	}
 
-	//Tab alignment
-	if (m_win->getScreen()->getTabPlacement() == PTOP ||
-			m_win->getScreen()->getTabPlacement() == PBOTTOM ||
-			m_win->isShaded()) {
-		switch(m_win->getScreen()->getTabAlignment()) {
-			case ARELATIVE:
-			case ALEFT:
-				pos_x = m_win->getXFrame(); 
-				break;
-			case ACENTER:
-				pos_x = calcCenterXPos(); 
-				break;
-			case ARIGHT:
-				pos_x = m_win->getXFrame() + m_win->getWidth() +
-						m_win->getScreen()->getBorderWidth2x() - m_size_w;
-				break;
-		}
-	} else { //PLeft |PRight
-		switch(m_win->getScreen()->getTabAlignment()) {
-			case ALEFT:
-				pos_y = m_win->getYFrame() - m_size_h + m_win->getHeight() +
-						m_win->getScreen()->getBorderWidth2x();
-				break;
-			case ACENTER:
-				pos_y = calcCenterYPos();
-				break;
-			case ARELATIVE:
-			case ARIGHT:
-				pos_y = m_win->getYFrame();
-				break;
-		}
-	}
-	
-	for (first = getFirst(this);
-			first!=0; 
-			pos_x += first->m_inc_x, pos_y += first->m_inc_y,
-			first = first->m_next){
+	for (tab = getFirst(this);
+			tab!=0; 
+			pos_x += tab->m_inc_x, pos_y += tab->m_inc_y,
+			tab = tab->m_next){
 		
-		XMoveWindow(m_display, first->m_tabwin, pos_x, pos_y);
+		XMoveWindow(m_display, tab->m_tabwin, pos_x, pos_y);
 				
-		//dont move fluxboxwindow if the itterator = this
-		if (first!=this) {
-			first->m_win->configure(m_win->getXFrame(), m_win->getYFrame(), 
+		//dont move FluxboxWindow if the iterator = this
+		if (tab!=this) {
+			tab->m_win->configure(m_win->getXFrame(), m_win->getYFrame(), 
 					m_win->getWidth(), m_win->getHeight());
 		}	
 	}	
-
-	m_stoptabs = false;
+	
+	m_stoptabs = false;//thaw tablist
 }
 
 //------------- calcIncrease ----------------
@@ -467,9 +541,9 @@ void Tab::calcIncrease(void) {
 	cerr << "Calculating tab increase" << endl;
 	#endif // DEBUG
 
-	Tab *first;
+	Tab *tab;
 	int inc_x = 0, inc_y = 0;
-	unsigned int tabs = 0, i = 0;
+	unsigned int i = 0, tabs = numObjects();
 
 	if (m_win->getScreen()->getTabPlacement() == PTOP ||
 			m_win->getScreen()->getTabPlacement() == PBOTTOM ||
@@ -489,6 +563,8 @@ void Tab::calcIncrease(void) {
 			case ARELATIVE:
 				inc_x = calcRelativeWidth();
 				break;
+			default:
+				break;
 		}
 	} else if (m_win->getScreen()->getTabPlacement() == PLEFT ||
 					m_win->getScreen()->getTabPlacement() == PRIGHT) {
@@ -507,12 +583,12 @@ void Tab::calcIncrease(void) {
 			case ARELATIVE:
 				inc_y = calcRelativeHeight();
 				break;
+			default:
+				break;
 		}
 	}
 
-	for (first = getFirst(this); first!=0; first = first->m_next, tabs++);
-
-	for (first = getFirst(this); first!=0; first = first->m_next, i++){
+	for (tab = getFirst(this); tab!=0; tab = tab->m_next, i++) {
 
 	//TODO: move this out from here?
 		if ((m_win->getScreen()->getTabPlacement() == PTOP ||
@@ -523,30 +599,30 @@ void Tab::calcIncrease(void) {
 					m_win->getScreen()->getBorderWidth2x()) % tabs) ||
 					i >= ((m_win->getWidth() +
 					m_win->getScreen()->getBorderWidth2x()) % tabs)) {
-				first->setTabWidth(inc_x);
-				first->m_inc_x = inc_x;
+				tab->setTabWidth(inc_x);
+				tab->m_inc_x = inc_x;
 			} else { // adding 1 extra pixel to get tabs like win width
-				first->setTabWidth(inc_x + 1);
-				first->m_inc_x = inc_x + 1;
+				tab->setTabWidth(inc_x + 1);
+				tab->m_inc_x = inc_x + 1;
 			}
-			first->m_inc_y = inc_y;
+			tab->m_inc_y = inc_y;
 		} else if (m_win->getScreen()->getTabAlignment() == ARELATIVE) {
 			if (!((m_win->getHeight() +
 				m_win->getScreen()->getBorderWidth2x()) % tabs) ||
 				i >= ((m_win->getHeight() +
 				m_win->getScreen()->getBorderWidth2x()) % tabs)) {
 
-				first->setTabHeight(inc_y);
-				first->m_inc_y = inc_y;
+				tab->setTabHeight(inc_y);
+				tab->m_inc_y = inc_y;
 			} else {
 				// adding 1 extra pixel to get tabs match window width
-				first->setTabHeight(inc_y + 1);
-				first->m_inc_y = inc_y + 1;
+				tab->setTabHeight(inc_y + 1);
+				tab->m_inc_y = inc_y + 1;
 			}
-			first->m_inc_x = inc_x;
+			tab->m_inc_x = inc_x;
 		} else { // non relative modes
-			first->m_inc_x = inc_x;
-			first->m_inc_y = inc_y;
+			tab->m_inc_x = inc_x;
+			tab->m_inc_y = inc_y;
 		}
 	}
 }
@@ -594,13 +670,11 @@ void Tab::buttonReleaseEvent(XButtonEvent *be) {
 							m_win->getScreen()->getRootWindow(),
 							be->x_root, be->y_root, &dest_x, &dest_y, &child)) {
 			
-			Tab *tab = 0;
-			FluxboxWindow *win = 0;
+			Tab *tab = Fluxbox::instance()->searchTab(child);
+			FluxboxWindow *win = Fluxbox::instance()->searchWindow(child);
 			//search tablist for a tabwindow
-			if (((tab = Fluxbox::instance()->searchTab(child))!=0) ||
-					(m_win->getScreen()->isSloppyWindowGrouping() &&
-					((win = Fluxbox::instance()->searchWindow(child))!=0) &&
-					(tab = win->getTab())!=0)) {
+			if ( (tab!=0) || (m_win->getScreen()->isSloppyWindowGrouping() &&
+					(win!=0) && (tab = win->getTab())!=0)) {
 
 				if (tab == this) // inserting ourself to ourself causes a disconnect
 					return;
@@ -616,7 +690,7 @@ void Tab::buttonReleaseEvent(XButtonEvent *be) {
 			} else {	
 				disconnect();
 
-				// convinience
+				// convenience
 				unsigned int placement = m_win->getScreen()->getTabPlacement();
 
 				// (ab)using dest_x and dest_y
@@ -638,6 +712,8 @@ void Tab::buttonReleaseEvent(XButtonEvent *be) {
 						case ARIGHT:
 							dest_x -= m_win->getWidth() - m_size_w;
 							break;
+						default:
+							break;
 					}
 
 				} else { // PLEFT & PRIGHT
@@ -651,6 +727,8 @@ void Tab::buttonReleaseEvent(XButtonEvent *be) {
 						case ALEFT:
 							dest_y -= m_win->getHeight() - m_size_h;
 							break;
+						default:
+							break;
 					}
 				}
 				//TODO: this causes an calculate increase event, even if we
@@ -956,7 +1034,7 @@ void Tab::setTabHeight(unsigned int h) {
 // ---------------------------------------
 void Tab::resizeGroup(void) {
 	#ifdef DEBUG
-	cerr << "Resising group" << endl;
+	cerr <<__FILE__<<"("<<__LINE__<<"): Resizing group"<<endl;
 	#endif //DEBUG
 	Tab *first;
 	for (first = getFirst(this); first != 0; first = first->m_next) {
@@ -987,16 +1065,23 @@ unsigned int Tab::calcRelativeWidth() {
 	return ((m_win->getWidth() + m_win->getScreen()->getBorderWidth2x())/num);
 }
 
+//--------------- numObjects -------------------
+// Returns the number of objects in
+// the TabGroup. 
+//-----------------------------------------------
+unsigned int Tab::numObjects() {
+	unsigned int num = 0;
+	for (Tab *tab = getFirst(this); tab != 0; tab = tab->m_next, num++);
+	return num;
+}
+
 //------------- calcRelativeHeight -------
 // Returns: Calculated height for relative 
 // alignment
 //----------------------------------------
 unsigned int Tab::calcRelativeHeight() {
-	unsigned int num=0;
-	//calculate num objs in list (extract this to a function?)
-	for (Tab *first=getFirst(this); first!=0; first=first->m_next, num++);	
-
-	return ((m_win->getHeight() + m_win->getScreen()->getBorderWidth2x())/num);
+	return ((m_win->getHeight() + 
+			m_win->getScreen()->getBorderWidth2x())/numObjects());
 }
 
 //------------- calcCenterXPos -----------
@@ -1004,11 +1089,8 @@ unsigned int Tab::calcRelativeHeight() {
 // centered alignment
 //----------------------------------------
 unsigned int Tab::calcCenterXPos() {
-	unsigned int num=0;
-	//calculate num objs in list (extract this to a function?)
-	for (Tab *first=getFirst(this); first!=0; first=first->m_next, num++);	
-
-	return (m_win->getXFrame() + ((m_win->getWidth() - (m_size_w * num)) / 2));
+	return (m_win->getXFrame() + ((m_win->getWidth() - 
+			(m_size_w * numObjects())) / 2));
 }
 
 //------------- calcCenterYPos -----------
@@ -1016,11 +1098,8 @@ unsigned int Tab::calcCenterXPos() {
 // centered alignment
 //----------------------------------------
 unsigned int Tab::calcCenterYPos() {
-	unsigned int num=0;
-	//calculate num objs in list (extract this to a function?)
-	for (Tab *first=getFirst(this); first!=0; first=first->m_next, num++);	
-
-	return (m_win->getYFrame() + ((m_win->getHeight() - (m_size_h * num)) / 2));
+	return (m_win->getYFrame() + ((m_win->getHeight() - 
+			(m_size_h * numObjects())) / 2));
 }
 
 
@@ -1028,7 +1107,7 @@ unsigned int Tab::calcCenterYPos() {
 // Returns the tabplacement string of the 
 // tabplacement number on success else 0.
 //----------------------------------------
-const char *Tab::getTabPlacementString(int placement) {	
+const char *Tab::getTabPlacementString(Tab::Placement placement) {	
 	for (int i=0; i<(PNONE / 5); i++) {
 		if (m_tabplacementlist[i] == placement)
 			return m_tabplacementlist[i].string;
@@ -1041,10 +1120,10 @@ const char *Tab::getTabPlacementString(int placement) {
 // tabplacement string on success else
 // the type none on failure.
 //----------------------------------------
-int Tab::getTabPlacementNum(const char *string) {
+Tab::Placement Tab::getTabPlacementNum(const char *string) {
 	for (int i=0; i<(PNONE / 5); i ++) {
 		if (m_tabplacementlist[i] == string) {
-			return m_tabplacementlist[i].tp;
+			return static_cast<Tab::Placement>(m_tabplacementlist[i].tp);
 		}
 	}
 	return PNONE;
@@ -1054,9 +1133,9 @@ int Tab::getTabPlacementNum(const char *string) {
 // Returns the tabplacement string of the 
 // tabplacement number on success else 0.
 //----------------------------------------
-const char *Tab::getTabAlignmentString(int placement) {	
+const char *Tab::getTabAlignmentString(Tab::Alignment alignment) {	
 	for (int i=0; i<ANONE; i++) {
-		if (m_tabalignmentlist[i] == placement)
+		if (m_tabalignmentlist[i] == alignment)
 			return m_tabalignmentlist[i].string;
 	}
 	return 0;
@@ -1067,10 +1146,10 @@ const char *Tab::getTabAlignmentString(int placement) {
 // tabplacement string on success else
 // the type none on failure.
 //----------------------------------------
-int Tab::getTabAlignmentNum(const char *string) {
+Tab::Alignment Tab::getTabAlignmentNum(const char *string) {
 	for (int i=0; i<ANONE; i++) {
 		if (m_tabalignmentlist[i] == string) {
-			return m_tabalignmentlist[i].tp;
+			return static_cast<Tab::Alignment>(m_tabalignmentlist[i].tp);
 		}
 	}
 	return ANONE;
